<?php

namespace SGalinski\SgMail\Domain\Repository;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use TYPO3\CMS\Extbase\Persistence\Generic\Query;
use TYPO3\CMS\Extbase\Persistence\QueryResultInterface;

/**
 * Repository for the Mail object
 */
class MailRepository extends AbstractRepository {
	/**
	 * Returns all mails that are still not sent ordered by priority.
	 *
	 * @param int $limit
	 * @return array|QueryResultInterface
	 */
	public function findMailsToSend($limit = NULL) {
		$query = $this->createQuery();
		if ($limit) {
			$query->setLimit($limit);
		}

		$query->setOrderings(['priority' => Query::ORDER_DESCENDING]);

		return $query->matching($query->equals('sent', FALSE))->execute();
	}

	/**
	 * @param string $extensionKey
	 * @param string $templateName
	 * @param int $limit
	 * @return array|QueryResultInterface
	 */
	public function findAllEntries($extensionKey, $templateName, $limit = NULL) {
		$query = $this->createQuery();
		if ($limit) {
			$query->setLimit($limit);
		}

		$query->setOrderings(['priority' => Query::ORDER_DESCENDING]);

		return $query->matching($query->equals('sent', FALSE))->execute();
	}
}
